<?php

namespace Litecms\Subcategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Subcategory\Models\Subcategories;

class SubcategoriesPolicy
{

    /**
     * Determine if the given user can view the subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function view(UserPolicy $user, Subcategories $subcategories)
    {
        if ($user->canDo('subcategory.subcategories.view') && $user->isAdmin()) {
            return true;
        }

        return $subcategories->user_id == user_id() && $subcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('subcategory.subcategories.create');
    }

    /**
     * Determine if the given user can update the given subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function update(UserPolicy $user, Subcategories $subcategories)
    {
        if ($user->canDo('subcategory.subcategories.edit') && $user->isAdmin()) {
            return true;
        }

        return $subcategories->user_id == user_id() && $subcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Subcategories $subcategories)
    {
        return $subcategories->user_id == user_id() && $subcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Subcategories $subcategories)
    {
        if ($user->canDo('subcategory.subcategories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subcategories.
     *
     * @param UserPolicy $user
     * @param Subcategories $subcategories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Subcategories $subcategories)
    {
        if ($user->canDo('subcategory.subcategories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
